<?php
/**
 * Atlantic back compat functionality
 *
 * Prevents Atlantic from running on WordPress versions prior to 4.7,
 * since this theme is not meant to be backward compatible beyond that and
 * relies on many newer functions and markup changes introduced in 4.7.
 *
 * @package Atlantic
 */

/**
 * Prevent switching to Atlantic on old versions of WordPress.
 *
 * Switches to the default theme.
 *
 * @since Atlantic 1.0.0
 */
function atlantic_switch_theme() {
	switch_theme( WP_DEFAULT_THEME );
	unset( $_GET['activated'] );
	add_action( 'admin_notices', 'atlantic_upgrade_notice' );
}
add_action( 'after_switch_theme', 'atlantic_switch_theme' );

/**
 * Static message for update notice.
 *
 * @return string
 */
function atlatic_require_message() {
	// translators: %s: Current WordPress version
	$message = sprintf( __( 'Atlantic requires at least WordPress version 4.7. You are running version %s. Please upgrade and try again.', 'atlantic' ), $GLOBALS['wp_version'] );
	return $message;
}

/**
 * Adds a message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * Atlantic on WordPress versions prior to 4.7.
 *
 * @since Atlantic 1.0.0
 *
 * @global string $wp_version WordPress version.
 */
function atlantic_upgrade_notice() {
	$message = atlatic_require_message();
	printf( '<div class="error"><p>%s</p></div>', wp_kses_post( wpautop( $message ) ) );
}

/**
 * Prevents the Customizer from being loaded on WordPress versions prior to 4.7.
 *
 * @since Atlantic 1.0.0
 *
 * @global string $wp_version WordPress version.
 */
function atlantic_customize() {
	$message = atlatic_require_message();
	wp_die( wp_kses_post( $message ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'atlantic_customize' );

/**
 * Prevents the Theme Preview from being loaded on WordPress versions prior to 4.7.
 *
 * @since Atlantic 1.0.0
 *
 * @global string $wp_version WordPress version.
 */
function atlantic_preview() {
	$message = atlatic_require_message();
	if ( isset( $_GET['preview'] ) ) {
		wp_die( wp_kses_post( $message ) );
	}
}
add_action( 'template_redirect', 'atlantic_preview' );
